@@ -4,11 +4,12 @@ for i in `find stamps -name "*.png"`
 do
   ls -l $i
 
-  rm tmp.png 2> /dev/null
+  #rm tmp.png 2> /dev/null
 
-  pngcrush -q $i tmp.png
+  pngout -q $i
+# 2>&1 > /dev/null
 
-  mv tmp.png $i 2> /dev/null
+  #mv tmp.png $i 2> /dev/null
 
   ls -l $i
 
