@@ -4,8 +4,9 @@ import sys, os, string
 from time import gmtime, strftime
 
 poHeader="""# Tuxpaint-stamps [Language] translation.
-# Copyright (C) 2002-"+"2008"
-# This file is distributed under the same license as the Tuxpaint-stamps package.
+# Copyright (C) 2002-"""+\
+strftime("%Y", gmtime())+"\n"\
+"""# This file is distributed under the same license as the Tuxpaint-stamps package.
 # [Translator's name] <translator@email.address>, """+\
 strftime("%Y", gmtime())+"\n"\
 """#
@@ -26,9 +27,15 @@ def lister(poLocale, dirname, filesindir):
     for fname in filesindir:
         fnlist = os.path.splitext(fname)
         if fnlist[1] == ".txt":
+            if os.path.exists(dirname + "/" + fnlist[0] + '.svg') : #Check for SVG
+                imgfile = fnlist[0] + '.svg'
+            else :
+                imgfile = fnlist[0] + '.png' # Else, assuming PNG
             txtFile = open(os.path.join(dirname, fname), 'rb')
             # write stamp filename down follow mark('#').
             poFile.write('\n#: ' + dirname + '/' + fnlist[0] + '\n')
+            # provide an URL for viewing the stamp online
+            poFile.write('#. View at http://www.tuxpaint.org/stamps/' + dirname[3:] + '/' + imgfile + '\n')
             # write description in msgid.
 	    line = txtFile.readline()
 	    if line[-1:] == "\n" :
